@@ -11,7 +11,7 @@ use Carp ();
 
 use MooX qw/late/;
 
-has '_formatter' => (isa => "Text::Format", is => 'rw',
+has '_formatter' => (is => 'rw',
     default => sub {
         return Text::Format->new(
             {
@@ -35,11 +35,11 @@ XML::Grammar::Fortune::ToText - convert the FortunesXML grammar to plaintext.
 
 =head1 VERSION
 
-Version 0.0512
+Version 0.0600
 
 =cut
 
-our $VERSION = '0.0512';
+our $VERSION = '0.0600';
 
 
 =head1 SYNOPSIS
